@@ -3,7 +3,7 @@ package cli
 import (
 	"fmt"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 
 	"github.com/spf13/cobra"
@@ -42,19 +42,23 @@ func init() {
 }
 
 func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
-	env := &platform.Shell{
-		CmdFlags: &platform.Flags{
-			Shell: shellName,
+	env := &runtime.Terminal{
+		CmdFlags: &runtime.Flags{
+			Shell:     shellName,
+			SaveCache: true,
 		},
 	}
+
 	env.Init()
 	defer env.Close()
+
 	switch feature {
 	case "notice":
 		if enable {
 			env.Cache().Delete(upgrade.CACHEKEY)
 			return
 		}
+
 		env.Cache().Set(upgrade.CACHEKEY, "disabled", -1)
 	default:
 		_ = cmd.Help()
